wsipipe.datasets package
========================

.. automodule:: wsipipe.datasets
   :members:
   :undoc-members:
   :show-inheritance:

camelyon16 module 
----------------------------------

.. automodule:: wsipipe.datasets.camelyon16
   :members:
   :undoc-members:
   :show-inheritance:

stripai module
-------------------------------

.. automodule:: wsipipe.datasets.stripai
   :members:
   :undoc-members:
   :show-inheritance:

dataset\_utils module
--------------------------------------

.. automodule:: wsipipe.datasets.dataset_utils
   :members:
   :undoc-members:
   :show-inheritance:

